# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: gogoproto/gogo.proto
# plugin: python-betterproto
from dataclasses import dataclass

import betterproto
from betterproto.grpc.grpclib_server import ServiceBase
